| Title: | Parse 'User-Agent' Strings |
|---|---|
| Description: | Despite there being a section in RFC 7231 <https://datatracker.ietf.org/doc/html/rfc7231#section-5.5.3> defining a suggested structure for 'User-Agent' headers this data is notoriously difficult to parse consistently. Tools are provided that will take in user agent strings and return structured R objects. This is a 'V8'-backed package based on the 'ua-parser' project <https://github.com/ua-parser>. |
| Authors: | Bob Rudis [aut, cph], Greg Hunt [aut, cre, cph], Lindsey Simon [aut] (uap-core), Tobie Langel [aut] (uap-core), Colman Humphrey [ctb] |
| Maintainer: | Greg Hunt <[email protected]> |
| License: | Apache License 2.0 | file LICENSE |
| Version: | 0.3.8 |
| Built: | 2026-05-09 08:21:39 UTC |
| Source: | https://github.com/gregfrog/uaparserjs |
Takes in a character vector of user agent strings and returns a data frame classed as tibble. of parsed user agents.
ua_parse(user_agents, .progress = FALSE) get_cache()ua_parse(user_agents, .progress = FALSE) get_cache()
user_agents |
a character vector of user agents |
.progress |
if 'TRUE' will display a progress bar in interactive mode |
a data frame classed as tibble with columns for user agent family, major & minor versions plus patch level along with OS family and major & minor versions plus device brand and model.
The regex YAML from uap-core is now updated when the package is rebuilt. The effective date can be found in the NEWS file.
<https://github.com/ua-parser/uap-core/>
ua_parse(paste0("Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.2 (KHTML, ", "like Gecko) Ubuntu/11.10 Chromium/15.0.874.106 ", "Chrome/15.0.874.106 Safari/535.2", collapse=""))ua_parse(paste0("Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.2 (KHTML, ", "like Gecko) Ubuntu/11.10 Chromium/15.0.874.106 ", "Chrome/15.0.874.106 Safari/535.2", collapse=""))
Despite there being a section in RFC 7231 <https://tools.ietf.org/html/rfc7231#section-5.5.3> defining a suggested structure for 'User-Agent' headers this data is notoriously difficult to parse consistently. Tools are provided that will take in user agent strings and return structured R objects. This is a 'V8'-backed package based on the 'ua-parser' project <https://github.com/ua-parser>.
The package incorporates regular expressions and test data from the ua parser project that are copyrighted by Google and the UA Parser contributors and are used under an Apache 2 license. See the UA parser project for details.
Bob Rudis (@hrbrmstr)
Useful links: